@@ -3,7 +3,7 @@ export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bi
 echo 'name: yesod-default
 version: 1.2.0
 id: yesod-default-1.2.0-5d724e6255914e391bee90b30a4cef13
-key: yesod_AOG2ytM5G0j6oQ9U6t59iZ
+key: yesod_FGqsltsIzlt9wknNONi20H
 license: MIT
 maintainer: Patrick Brisbin <pbrisbin@gmail.com>
 stability: Stable
@@ -21,10 +21,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-default-1.2.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-default-1.2.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-default-1.2.0
-hs-libraries: HSyesod-default-1.2.0-AOG2ytM5G0j6oQ9U6t59iZ
+hs-libraries: HSyesod-default-1.2.0-FGqsltsIzlt9wknNONi20H
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    yesod-core-1.4.18.1-1427f09c60204e2c904ad1c11de4a4ba
+    yesod-core-1.4.18.2-1c2aab5a100ce9de89ec3a6e919507f9
 haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
 haddock-html: /usr/share/doc/haskell-yesod-default/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
